@@ -40,7 +40,7 @@ go_file_opener_finalize (GObject *obj)
 {
 	GOFileOpener *fo;
 
-	g_return_if_fail (IS_GO_FILE_OPENER (obj));
+	g_return_if_fail (GO_IS_FILE_OPENER (obj));
 
 	fo = GO_FILE_OPENER (obj);
 	g_free (fo->id);
@@ -54,14 +54,14 @@ go_file_opener_finalize (GObject *obj)
 }
 
 static gboolean
-go_file_opener_can_probe_real (GOFileOpener const *fo, FileProbeLevel pl)
+go_file_opener_can_probe_real (GOFileOpener const *fo, GOFileProbeLevel pl)
 {
 	return fo->probe_func != NULL;
 }
 
 static gboolean
 go_file_opener_probe_real (GOFileOpener const *fo, GsfInput *input,
-			   FileProbeLevel pl)
+			   GOFileProbeLevel pl)
 {
 	gboolean ret = FALSE;
 
@@ -74,7 +74,7 @@ go_file_opener_probe_real (GOFileOpener const *fo, GsfInput *input,
 
 static void
 go_file_opener_open_real (GOFileOpener const *fo, gchar const *opt_enc,
-			  IOContext *io_context,
+			  GOIOContext *io_context,
 			  gpointer FIXME_workbook_view,
 			  GsfInput *input)
 {
@@ -87,7 +87,7 @@ go_file_opener_open_real (GOFileOpener const *fo, gchar const *opt_enc,
 			fo->open_func (fo, io_context,
 				       FIXME_workbook_view, input);
 	} else
-		gnumeric_io_error_unknown (io_context);
+		go_io_error_unknown (io_context);
 }
 
 static void
@@ -128,7 +128,7 @@ go_file_opener_setup (GOFileOpener *fo, gchar const *id,
 		      GOFileOpenerProbeFunc probe_func,
 		      GOFileOpenerOpenFunc open_func)
 {
-	g_return_if_fail (IS_GO_FILE_OPENER (fo));
+	g_return_if_fail (GO_IS_FILE_OPENER (fo));
 
 	fo->id = g_strdup (id);
 	fo->description = g_strdup (description);
@@ -164,7 +164,7 @@ go_file_opener_new (gchar const *id,
 {
 	GOFileOpener *fo;
 
-	fo = GO_FILE_OPENER (g_object_new (TYPE_GO_FILE_OPENER, NULL));
+	fo = GO_FILE_OPENER (g_object_new (GO_TYPE_FILE_OPENER, NULL));
 	go_file_opener_setup (fo, id, description, suffixes, mimes, FALSE,
 			      probe_func, open_func);
 
@@ -195,7 +195,7 @@ go_file_opener_new_with_enc (gchar const *id,
 {
         GOFileOpener *fo;
 
-        fo = GO_FILE_OPENER (g_object_new (TYPE_GO_FILE_OPENER, NULL));
+        fo = GO_FILE_OPENER (g_object_new (GO_TYPE_FILE_OPENER, NULL));
         go_file_opener_setup (fo, id, description, suffixes, mimes, TRUE,
 			      probe_func, (GOFileOpenerOpenFunc)open_func);
         return fo;
@@ -207,7 +207,7 @@ go_file_opener_new_with_enc (gchar const *id,
 gchar const *
 go_file_opener_get_id (GOFileOpener const *fo)
 {
-	g_return_val_if_fail (IS_GO_FILE_OPENER (fo), NULL);
+	g_return_val_if_fail (GO_IS_FILE_OPENER (fo), NULL);
 
 	return fo->id;
 }
@@ -215,7 +215,7 @@ go_file_opener_get_id (GOFileOpener const *fo)
 gchar const *
 go_file_opener_get_description (GOFileOpener const *fo)
 {
-	g_return_val_if_fail (IS_GO_FILE_OPENER (fo), NULL);
+	g_return_val_if_fail (GO_IS_FILE_OPENER (fo), NULL);
 
 	return fo->description;
 }
@@ -223,15 +223,15 @@ go_file_opener_get_description (GOFileOpener const *fo)
 gboolean
 go_file_opener_is_encoding_dependent (GOFileOpener const *fo)
 {
-        g_return_val_if_fail (IS_GO_FILE_OPENER (fo), FALSE);
+        g_return_val_if_fail (GO_IS_FILE_OPENER (fo), FALSE);
 
 	return fo->encoding_dependent;
 }
 
 gboolean
-go_file_opener_can_probe (GOFileOpener const *fo, FileProbeLevel pl)
+go_file_opener_can_probe (GOFileOpener const *fo, GOFileProbeLevel pl)
 {
-	g_return_val_if_fail (IS_GO_FILE_OPENER (fo), FALSE);
+	g_return_val_if_fail (GO_IS_FILE_OPENER (fo), FALSE);
 
 	return GO_FILE_OPENER_METHOD (fo, can_probe) (fo, pl);
 }
@@ -239,13 +239,13 @@ go_file_opener_can_probe (GOFileOpener const *fo, FileProbeLevel pl)
 GSList const *
 go_file_opener_get_suffixes (GOFileOpener const *fo)
 {
-	g_return_val_if_fail (IS_GO_FILE_OPENER (fo), NULL);
+	g_return_val_if_fail (GO_IS_FILE_OPENER (fo), NULL);
 	return fo->suffixes;
 }
 GSList const *
 go_file_opener_get_mimes (GOFileOpener const *fo)
 {
-	g_return_val_if_fail (IS_GO_FILE_OPENER (fo), NULL);
+	g_return_val_if_fail (GO_IS_FILE_OPENER (fo), NULL);
 	return fo->mimes;
 }
 
@@ -254,16 +254,16 @@ go_file_opener_get_mimes (GOFileOpener const *fo)
  * go_file_opener_probe:
  * @fo      : #GOFileOpener
  * @input   : #GsfInput
- * @pl	    : #FileProbeLevel
+ * @pl	    : #GOFileProbeLevel
  *
  * Checks if a given file is supported by the opener.
  *
  * Returns: %TRUE, if the opener can read given file and %FALSE otherwise.
  **/
 gboolean
-go_file_opener_probe (GOFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
+go_file_opener_probe (GOFileOpener const *fo, GsfInput *input, GOFileProbeLevel pl)
 {
-	g_return_val_if_fail (IS_GO_FILE_OPENER (fo), FALSE);
+	g_return_val_if_fail (GO_IS_FILE_OPENER (fo), FALSE);
 	g_return_val_if_fail (GSF_IS_INPUT (input), FALSE);
 
 #if 0
@@ -284,16 +284,16 @@ go_file_opener_probe (GOFileOpener const *fo, GsfInput *input, FileProbeLevel pl
  *
  * Reads content of @file_name file into workbook @wbv is attached to.
  * Results are reported using @io_context object, use
- * gnumeric_io_error_occurred to find out if operation was successful.
+ * go_io_error_occurred to find out if operation was successful.
  * The state of @wbv and its workbook is undefined if operation fails, you
  * should destroy them in that case.
  */
 void
 go_file_opener_open (GOFileOpener const *fo, gchar const *opt_enc,
-		     IOContext *io_context,
+		     GOIOContext *io_context,
 		     gpointer FIXME_workbook_view, GsfInput *input)
 {
-	g_return_if_fail (IS_GO_FILE_OPENER (fo));
+	g_return_if_fail (GO_IS_FILE_OPENER (fo));
 	g_return_if_fail (GSF_IS_INPUT (input));
 
 	GO_FILE_OPENER_METHOD (fo, open) (fo, opt_enc, io_context,
@@ -312,8 +312,8 @@ go_file_saver_init (GOFileSaver *fs)
 	fs->mime_type = NULL;
 	fs->description = NULL;
 	fs->overwrite_files = TRUE;
-	fs->format_level = FILE_FL_NEW;
-	fs->save_scope = FILE_SAVE_WORKBOOK;
+	fs->format_level = GO_FILE_FL_NEW;
+	fs->save_scope = GO_FILE_SAVE_WORKBOOK;
 	fs->save_func = NULL;
 }
 
@@ -322,7 +322,7 @@ go_file_saver_finalize (GObject *obj)
 {
 	GOFileSaver *fs;
 
-	g_return_if_fail (IS_GO_FILE_SAVER (obj));
+	g_return_if_fail (GO_IS_FILE_SAVER (obj));
 
 	fs = GO_FILE_SAVER (obj);
 	g_free (fs->id);
@@ -432,11 +432,11 @@ go_file_saver_get_property (GObject *object, guint property_id,
 }
 
 static void
-go_file_saver_save_real (GOFileSaver const *fs, IOContext *io_context,
+go_file_saver_save_real (GOFileSaver const *fs, GOIOContext *io_context,
 			 gconstpointer FIXME_workbook_view, GsfOutput *output)
 {
 	if (fs->save_func == NULL) {
-		gnumeric_io_error_unknown (io_context);
+		go_io_error_unknown (io_context);
 		return;
 	}
 
@@ -509,9 +509,9 @@ go_file_saver_class_init (GOFileSaverClass *klass)
 		 FS_PROP_FORMAT_LEVEL,
 		 g_param_spec_enum ("format-level",
 				    _("Format Level"),
-				    _(""),
-				    GO_FILE_SAVER_LEVEL_TYPE,
-				    FILE_FL_NEW,
+				    "?",
+				    GO_TYPE_FILE_SAVER_LEVEL,
+				    GO_FILE_FL_NEW,
 				    GSF_PARAM_STATIC |
 				    G_PARAM_READWRITE));
 
@@ -521,8 +521,8 @@ go_file_saver_class_init (GOFileSaverClass *klass)
 		 g_param_spec_enum ("scope",
 				    _("Scope"),
 				    _("How much of a document is saved"),
-				    GO_FILE_SAVER_SCOPE_TYPE,
-				    FILE_SAVE_WORKBOOK,
+				    GO_TYPE_FILE_SAVER_SCOPE,
+				    GO_FILE_SAVE_WORKBOOK,
 				    GSF_PARAM_STATIC |
 				    G_PARAM_READWRITE));
 
@@ -537,7 +537,7 @@ go_file_saver_class_init (GOFileSaverClass *klass)
 			      NULL, NULL,
 			      go__BOOLEAN__OBJECT_STRING_POINTER,
 			      G_TYPE_BOOLEAN,
-			      3, GO_DOC_TYPE, G_TYPE_STRING, G_TYPE_POINTER);
+			      3, GO_TYPE_DOC, G_TYPE_STRING, G_TYPE_POINTER);
 }
 
 GSF_CLASS (GOFileSaver, go_file_saver,
@@ -562,12 +562,12 @@ GOFileSaver *
 go_file_saver_new (gchar const *id,
 		   gchar const *extension,
 		   gchar const *description,
-		   FileFormatLevel level,
+		   GOFileFormatLevel level,
 		   GOFileSaverSaveFunc save_func)
 {
 	GOFileSaver *fs;
 
-	fs = GO_FILE_SAVER (g_object_new (TYPE_GO_FILE_SAVER,
+	fs = GO_FILE_SAVER (g_object_new (GO_TYPE_FILE_SAVER,
 					  "id", id,
 					  "extension", extension,
 					  "description", description,
@@ -579,18 +579,18 @@ go_file_saver_new (gchar const *id,
 }
 
 void
-go_file_saver_set_save_scope (GOFileSaver *fs, FileSaveScope scope)
+go_file_saver_set_save_scope (GOFileSaver *fs, GOFileSaveScope scope)
 {
-	g_return_if_fail (IS_GO_FILE_SAVER (fs));
-	g_return_if_fail (scope < FILE_SAVE_LAST);
+	g_return_if_fail (GO_IS_FILE_SAVER (fs));
+	g_return_if_fail (scope < GO_FILE_SAVE_LAST);
 
 	fs->save_scope = scope;
 }
 
-FileSaveScope
+GOFileSaveScope
 go_file_saver_get_save_scope (GOFileSaver const *fs)
 {
-	g_return_val_if_fail (IS_GO_FILE_SAVER (fs), FILE_SAVE_WORKBOOK);
+	g_return_val_if_fail (GO_IS_FILE_SAVER (fs), GO_FILE_SAVE_WORKBOOK);
 
 	return fs->save_scope;
 }
@@ -598,7 +598,7 @@ go_file_saver_get_save_scope (GOFileSaver const *fs)
 gchar const *
 go_file_saver_get_id (GOFileSaver const *fs)
 {
-	g_return_val_if_fail (IS_GO_FILE_SAVER (fs), NULL);
+	g_return_val_if_fail (GO_IS_FILE_SAVER (fs), NULL);
 
 	return fs->id;
 }
@@ -606,7 +606,7 @@ go_file_saver_get_id (GOFileSaver const *fs)
 gchar const *
 go_file_saver_get_mime_type (GOFileSaver const *fs)
 {
-	g_return_val_if_fail (IS_GO_FILE_SAVER (fs), NULL);
+	g_return_val_if_fail (GO_IS_FILE_SAVER (fs), NULL);
 
 	return fs->mime_type;
 }
@@ -614,7 +614,7 @@ go_file_saver_get_mime_type (GOFileSaver const *fs)
 gchar const *
 go_file_saver_get_extension (GOFileSaver const *fs)
 {
-	g_return_val_if_fail (IS_GO_FILE_SAVER (fs), NULL);
+	g_return_val_if_fail (GO_IS_FILE_SAVER (fs), NULL);
 
 	return fs->extension;
 }
@@ -622,15 +622,15 @@ go_file_saver_get_extension (GOFileSaver const *fs)
 gchar const *
 go_file_saver_get_description (GOFileSaver const *fs)
 {
-	g_return_val_if_fail (IS_GO_FILE_SAVER (fs), NULL);
+	g_return_val_if_fail (GO_IS_FILE_SAVER (fs), NULL);
 
 	return fs->description;
 }
 
-FileFormatLevel
+GOFileFormatLevel
 go_file_saver_get_format_level (GOFileSaver const *fs)
 {
-	g_return_val_if_fail (IS_GO_FILE_SAVER (fs), FILE_FL_NEW);
+	g_return_val_if_fail (GO_IS_FILE_SAVER (fs), GO_FILE_FL_NEW);
 
 	return fs->format_level;
 }
@@ -657,16 +657,16 @@ go_file_saver_set_export_options (GOFileSaver *fs,
  *
  * Saves @wbv and the workbook it is attached to into @output stream.
  * Results are reported using @io_context object, use
- * gnumeric_io_error_occurred to find out if operation was successful.
+ * go_io_error_occurred to find out if operation was successful.
  * It's possible that @file_name is created and contain some data if
  * operation fails, you should remove the file in that case.
  */
 void
-go_file_saver_save (GOFileSaver const *fs, IOContext *io_context,
+go_file_saver_save (GOFileSaver const *fs, GOIOContext *io_context,
 		    gconstpointer FIXME_workbook_view,
 		    GsfOutput *output)
 {
-	g_return_if_fail (IS_GO_FILE_SAVER (fs));
+	g_return_if_fail (GO_IS_FILE_SAVER (fs));
 	g_return_if_fail (GSF_IS_OUTPUT (output));
 
 	if (GSF_IS_OUTPUT_STDIO (output)) {
@@ -683,19 +683,19 @@ go_file_saver_save (GOFileSaver const *fs, IOContext *io_context,
 		if (!fs->overwrite_files &&
 		    file_name &&
 		    g_file_test (file_name, G_FILE_TEST_EXISTS)) {
-			ErrorInfo *save_error;
+			GOErrorInfo *save_error;
 			const char *msg = _("Saving over old files of this type is disabled for safety.");
 
 			if (!gsf_output_error (output))
-				gsf_output_set_error (output, 0, msg);
+				gsf_output_set_error (output, 0, "%s", msg);
 
 			g_free (file_name);
 
-			save_error = error_info_new_str_with_details (
+			save_error = go_error_info_new_str_with_details (
 				msg,
-				error_info_new_str (
+				go_error_info_new_str (
 					_("You can turn this safety feature off by editing appropriate plugin.xml file.")));
-			gnumeric_io_error_info_set (io_context, save_error);
+			go_io_error_info_set (io_context, save_error);
 			return;
 		}
 
@@ -719,7 +719,7 @@ go_file_saver_save (GOFileSaver const *fs, IOContext *io_context,
 void
 go_file_saver_set_overwrite_files (GOFileSaver *fs, gboolean overwrite)
 {
-	g_return_if_fail (IS_GO_FILE_SAVER (fs));
+	g_return_if_fail (GO_IS_FILE_SAVER (fs));
 
 	fs->overwrite_files = overwrite;
 }
@@ -730,12 +730,12 @@ go_file_saver_level_get_type (void)
 	static GType etype = 0;
 	if (etype == 0) {
 		static GEnumValue values[] = {
-			{ FILE_FL_NONE, (char*)"GO_FILE_SAVER_LEVEL_NONE", (char*)"none" },
-			{ FILE_FL_WRITE_ONLY, (char*)"GO_FILE_SAVER_LEVEL_WRITE_ONLY", (char*)"write_only" },
-			{ FILE_FL_NEW, (char*)"GO_FILE_SAVER_LEVEL_NEW", (char*)"new" },
-			{ FILE_FL_MANUAL, (char*)"GO_FILE_SAVER_LEVEL_MANUAL", (char*)"manual" },
-			{ FILE_FL_MANUAL_REMEMBER, (char*)"GO_FILE_SAVER_LEVEL_MANUAL_REMEMBER", (char*)"manual_remember" },
-			{ FILE_FL_AUTO, (char*)"GO_FILE_SAVER_LEVEL_AUTO", (char*)"auto" },
+			{ GO_FILE_FL_NONE, (char*)"GO_FILE_SAVER_LEVEL_NONE", (char*)"none" },
+			{ GO_FILE_FL_WRITE_ONLY, (char*)"GO_FILE_SAVER_LEVEL_WRITE_ONLY", (char*)"write_only" },
+			{ GO_FILE_FL_NEW, (char*)"GO_FILE_SAVER_LEVEL_NEW", (char*)"new" },
+			{ GO_FILE_FL_MANUAL, (char*)"GO_FILE_SAVER_LEVEL_MANUAL", (char*)"manual" },
+			{ GO_FILE_FL_MANUAL_REMEMBER, (char*)"GO_FILE_SAVER_LEVEL_MANUAL_REMEMBER", (char*)"manual_remember" },
+			{ GO_FILE_FL_AUTO, (char*)"GO_FILE_SAVER_LEVEL_AUTO", (char*)"auto" },
 			{ 0, NULL, NULL }
 		};
 		etype = g_enum_register_static ("GOFileSaverLevel", values);
@@ -749,9 +749,9 @@ go_file_saver_scope_get_type (void)
 	static GType etype = 0;
 	if (etype == 0) {
 		static GEnumValue values[] = {
-			{ FILE_SAVE_WORKBOOK, (char*)"GO_FILE_SAVER_SCOPE_WORKBOOK", (char*)"workbook" },
-			{ FILE_SAVE_SHEET, (char*)"GO_FILE_SAVER_SCOPE_SHEET", (char*)"sheet" },
-			{ FILE_SAVE_RANGE, (char*)"GO_FILE_SAVER_SCOPE_RANGE", (char*)"range" },
+			{ GO_FILE_SAVE_WORKBOOK, (char*)"GO_FILE_SAVER_SCOPE_WORKBOOK", (char*)"workbook" },
+			{ GO_FILE_SAVE_SHEET, (char*)"GO_FILE_SAVER_SCOPE_SHEET", (char*)"sheet" },
+			{ GO_FILE_SAVE_RANGE, (char*)"GO_FILE_SAVER_SCOPE_RANGE", (char*)"range" },
 			{ 0, NULL, NULL }
 		};
 		etype = g_enum_register_static ("GOFileSaverScope", values);
@@ -804,7 +804,7 @@ go_file_opener_register (GOFileOpener *fo, gint priority)
 	gint pos;
 	gchar const *id;
 
-	g_return_if_fail (IS_GO_FILE_OPENER (fo));
+	g_return_if_fail (GO_IS_FILE_OPENER (fo));
 	g_return_if_fail (priority >=0 && priority <= 100);
 
 	pos = go_list_index_custom (file_opener_priority_list,
@@ -839,7 +839,7 @@ go_file_opener_unregister (GOFileOpener *fo)
 	GList *l;
 	gchar const *id;
 
-	g_return_if_fail (IS_GO_FILE_OPENER (fo));
+	g_return_if_fail (GO_IS_FILE_OPENER (fo));
 
 	pos = g_list_index (file_opener_list, fo);
 	g_return_if_fail (pos != -1);
@@ -882,7 +882,7 @@ go_file_saver_register (GOFileSaver *fs)
 {
 	gchar const *id;
 
-	g_return_if_fail (IS_GO_FILE_SAVER (fs));
+	g_return_if_fail (GO_IS_FILE_SAVER (fs));
 
 	file_saver_list = g_list_prepend (file_saver_list, fs);
 	g_object_ref (G_OBJECT (fs));
@@ -912,7 +912,7 @@ go_file_saver_register_as_default (GOFileSaver *fs, gint priority)
 {
 	DefaultFileSaver *dfs;
 
-	g_return_if_fail (IS_GO_FILE_SAVER (fs));
+	g_return_if_fail (GO_IS_FILE_SAVER (fs));
 	g_return_if_fail (priority >=0 && priority <= 100);
 
 	go_file_saver_register (fs);
@@ -939,7 +939,7 @@ go_file_saver_unregister (GOFileSaver *fs)
 	GList *l;
 	gchar const *id;
 
-	g_return_if_fail (IS_GO_FILE_SAVER (fs));
+	g_return_if_fail (GO_IS_FILE_SAVER (fs));
 
 	l = g_list_find (file_saver_list, fs);
 	g_return_if_fail (l != NULL);
@@ -996,12 +996,24 @@ go_file_saver_for_mime_type (gchar const *mime_type)
 {
 	GList *l;
 
-	for (l = file_saver_list; l != NULL; l = l->next) {
-		if (!strcmp (go_file_saver_get_mime_type (l->data), mime_type)) {
-			return (l->data);
-		}
+	g_return_val_if_fail (mime_type != NULL, NULL);
+
+	for (l = default_file_saver_list ; l != NULL; l = l->next) {
+		DefaultFileSaver *dfs = l->data;
+		GOFileSaver *fs = dfs->saver;
+		const char *this_type = go_file_saver_get_mime_type (fs);
+		if (this_type && !strcmp (this_type, mime_type))
+			return fs;
 	}
-	return (NULL);
+
+	for (l = file_saver_list; l != NULL; l = l->next) {
+		GOFileSaver *fs = l->data;
+		const char *this_type = go_file_saver_get_mime_type (fs);
+		if (this_type && !strcmp (this_type, mime_type))
+			return fs;
+	}
+
+	return NULL;
 }
 
 /**
@@ -1019,6 +1031,10 @@ go_file_saver_for_file_name (char const *file_name)
 	GList *l;
 	char const *extension = gsf_extension_pointer (file_name);
 
+	for (l = default_file_saver_list ; l != NULL; l = l->next)
+		if (!strcmp (go_file_saver_get_extension (((DefaultFileSaver *)(l->data))->saver), extension))
+			return ((DefaultFileSaver *)(l->data))->saver;
+
 	for (l = file_saver_list; l != NULL; l = l->next)
 		if (!strcmp (go_file_saver_get_extension (l->data), extension))
 			return l->data;
