@@ -52,10 +52,15 @@
 
 #ifdef G_OS_WIN32
 #define STRICT
-#include <windows.h>	// pickup HMODULE
+/* pickup HMODULE */
+#include <windows.h>
 #undef STRICT
 #endif
 
+#ifdef GOFFICE_WITH_LASEM
+#include <goffice/graph/gog-equation.h>
+#endif
+
 int goffice_graph_debug_level = 0;
 
 static char const *libgoffice_data_dir   = GOFFICE_DATADIR;
@@ -82,7 +87,7 @@ go_sys_lib_dir (void)
 }
 
 void
-libgoffice_init ()
+libgoffice_init (void)
 {
 	static gboolean initialized = FALSE;
 
@@ -94,7 +99,7 @@ libgoffice_init ()
 	gchar *dir;
 
 #define S(s)	#s
-	char const *module_name = 
+	char const *module_name =
 		"libgoffice-" S(GO_VERSION_EPOCH) "-" S(GO_VERSION_MAJOR) ".dll";
 #undef S
 	wchar_t *wc_module_name = g_utf8_to_utf16 (module_name, -1, NULL, NULL, NULL);
@@ -116,53 +121,60 @@ libgoffice_init ()
 
 	bindtextdomain (GETTEXT_PACKAGE, libgoffice_locale_dir);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-	go_conf_init ();
-	go_fonts_init ();
-	go_math_init ();
+	g_type_init ();
 	gsf_init ();
 
+	_go_string_init ();
+	_go_conf_init ();
+	_go_fonts_init ();
+	_go_math_init ();
+
 	/* keep trigger happy linkers from leaving things out */
-	plugin_services_init ();
-	gog_plugin_services_init ();
+	_go_plugin_services_init ();
+	_gog_plugin_services_init ();
 #ifdef GOFFICE_WITH_GTK
-	goc_plugin_services_init ();
+	_goc_plugin_services_init ();
 #endif
-	(void) GOG_GRAPH_TYPE;
-	(void) GOG_CHART_TYPE;
-	(void) GOG_PLOT_TYPE;
-	(void) GOG_SERIES_TYPE;
-	(void) GOG_SERIES_ELEMENT_TYPE;
-	(void) GOG_LEGEND_TYPE;
-	(void) GOG_AXIS_TYPE;
-	(void) GOG_AXIS_LINE_TYPE;
-	(void) GOG_LABEL_TYPE;
-	(void) GOG_GRID_TYPE;
-	(void) GOG_GRID_LINE_TYPE;
-	(void) GOG_ERROR_BAR_TYPE;
-	(void) GOG_REG_EQN_TYPE;
-	(void) GOG_SERIES_LINES_TYPE;
-	(void) GO_DATA_SCALAR_VAL_TYPE;
-	(void) GO_DATA_SCALAR_STR_TYPE;
+	(void) GOG_TYPE_GRAPH;
+	(void) GOG_TYPE_CHART;
+	(void) GOG_TYPE_PLOT;
+	(void) GOG_TYPE_SERIES;
+	(void) GOG_TYPE_SERIES_ELEMENT;
+	(void) GOG_TYPE_LEGEND;
+	(void) GOG_TYPE_AXIS;
+	(void) GOG_TYPE_AXIS_LINE;
+	(void) GOG_TYPE_LABEL;
+	(void) GOG_TYPE_GRID;
+	(void) GOG_TYPE_GRID_LINE;
+#ifdef GOFFICE_WITH_LASEM
+	(void) GOG_TYPE_EQUATION;
+#endif
+	(void) GOG_TYPE_ERROR_BAR;
+	(void) GOG_TYPE_REG_EQN;
+	(void) GOG_TYPE_SERIES_LINES;
+	(void) GO_TYPE_DATA_SCALAR_VAL;
+	(void) GO_TYPE_DATA_SCALAR_STR;
 	(void) GOG_3D_BOX_TYPE;
-	gog_themes_init	();
-	go_number_format_init ();
-	go_currency_date_format_init ();
-	go_distributions_init ();
+	_gog_themes_init ();
+	_go_number_format_init ();
+	_go_currency_date_format_init ();
+	_go_distributions_init ();
 	initialized = TRUE;
 }
 
 void
 libgoffice_shutdown (void)
 {
-	gog_themes_shutdown ();
-	go_fonts_shutdown ();
-	go_conf_shutdown ();
+	_gog_themes_shutdown ();
+	_go_fonts_shutdown ();
+	_go_conf_shutdown ();
 #ifdef GOFFICE_WITH_GTK
-	goc_plugin_services_shutdown ();
+	_goc_plugin_services_shutdown ();
 #endif
-	gog_plugin_services_shutdown ();
-	go_currency_date_format_shutdown ();
-	go_number_format_shutdown ();
+	_gog_plugin_services_shutdown ();
+	_go_currency_date_format_shutdown ();
+	_go_number_format_shutdown ();
+	_go_string_shutdown ();
 #ifdef G_OS_WIN32
 	/* const_cast, we created these above */
 	g_free ((char *)libgoffice_data_dir);
