@@ -20,25 +20,7 @@
  */
 
 #include <goffice/goffice-config.h>
-#include <goffice/graph/gog-axis.h>
-#include <goffice/graph/gog-chart.h>
-#include <goffice/graph/gog-chart-map.h>
-#include <goffice/graph/gog-chart-map-3d.h>
-#include <goffice/graph/gog-data-allocator.h>
-#include <goffice/graph/gog-grid-line.h>
-#include <goffice/graph/gog-renderer.h>
-#include <goffice/graph/gog-style.h>
-#include <goffice/graph/gog-styled-object.h>
-#include <goffice/graph/gog-theme.h>
-#include <goffice/graph/gog-view.h>
-#include <goffice/data/go-data.h>
-
-#include <goffice/math/go-math.h>
-#include <goffice/utils/go-format.h>
-
-#ifdef GOFFICE_WITH_GTK
-#include <goffice/gtk/goffice-gtk.h>
-#endif
+#include <goffice/goffice.h>
 
 #include <glib/gi18n-lib.h>
 
@@ -63,15 +45,15 @@ enum {
 gboolean
 gog_grid_line_is_minor (GogGridLine *ggl)
 {
-	g_return_val_if_fail (IS_GOG_GRID_LINE (ggl), FALSE);
+	g_return_val_if_fail (GOG_IS_GRID_LINE (ggl), FALSE);
 
 	return ggl->is_minor;
 }
 
 static void
-gog_grid_line_init_style (GogStyledObject *gso, GogStyle *style)
+gog_grid_line_init_style (GogStyledObject *gso, GOStyle *style)
 {
-	style->interesting_fields = GOG_STYLE_LINE | GOG_STYLE_FILL;
+	style->interesting_fields = GO_STYLE_LINE | GO_STYLE_FILL;
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
 		style, GOG_OBJECT (gso), 0, FALSE);
 }
@@ -87,7 +69,7 @@ gog_grid_line_set_property (GObject *obj, guint param_id,
 			grid_line->is_minor = g_value_get_boolean (value);
 			break;
 
-		default: 
+		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 			return; /* NOTE : RETURN */
 	}
@@ -106,7 +88,7 @@ gog_grid_line_get_property (GObject *obj, guint param_id,
 			g_value_set_boolean (value, grid_line->is_minor);
 			break;
 
-		default: 
+		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 			 break;
 	}
@@ -123,26 +105,26 @@ gog_grid_line_class_init (GogGridLineClass *klass)
 	gobject_klass->get_property = gog_grid_line_get_property;
 	gog_klass->view_type	= gog_grid_line_view_get_type ();
 	style_klass->init_style = gog_grid_line_init_style;
-	
+
 	g_object_class_install_property (gobject_klass, GRID_LINE_PROP_IS_MINOR,
-		g_param_spec_boolean ("is-minor", 
+		g_param_spec_boolean ("is-minor",
 			_("Is-minor"),
-			_("Are these minor grid lines"), 
-			FALSE, 
+			_("Are these minor grid lines"),
+			FALSE,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 }
 
 GSF_CLASS (GogGridLine, gog_grid_line,
 	   gog_grid_line_class_init, NULL,
-	   GOG_STYLED_OBJECT_TYPE)
+	   GOG_TYPE_STYLED_OBJECT)
 
 /************************************************************************/
 
 typedef GogViewClass	GogGridLineViewClass;
 
-#define GOG_GRID_LINE_VIEW_TYPE		(gog_grid_line_view_get_type ())
-#define GOG_GRID_LINE_VIEW(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_GRID_LINE_VIEW_TYPE, GogGridLineView))
-#define IS_GOG_GRID_LINE_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_GRID_LINE_VIEW_TYPE))
+#define GOG_TYPE_GRID_LINE_VIEW		(gog_grid_line_view_get_type ())
+#define GOG_GRID_LINE_VIEW(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_GRID_LINE_VIEW, GogGridLineView))
+#define GOG_IS_GRID_LINE_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_GRID_LINE_VIEW))
 
 static void
 gog_grid_line_xy_render (GogGridLine *grid_line, GogView *view,
@@ -393,7 +375,7 @@ gog_grid_line_xyz_render (GogGridLine *grid_line, GogView *view,
 				}
 			} else {
 				for (i = 0; i < tick_nbr; ++i) {
-					if (!((ticks[i].type == GOG_AXIS_TICK_MAJOR 
+					if (!((ticks[i].type == GOG_AXIS_TICK_MAJOR
 					       && !grid_line->is_minor) ||
 					      (ticks[i].type == GOG_AXIS_TICK_MINOR
 					       && grid_line->is_minor)))
@@ -476,7 +458,7 @@ gog_grid_line_xyz_render (GogGridLine *grid_line, GogView *view,
 				}
 			} else {
 				for (i = 0; i < tick_nbr; ++i) {
-					if (!((ticks[i].type == GOG_AXIS_TICK_MAJOR 
+					if (!((ticks[i].type == GOG_AXIS_TICK_MAJOR
 					       && !grid_line->is_minor) ||
 					      (ticks[i].type == GOG_AXIS_TICK_MINOR
 					       && grid_line->is_minor)))
@@ -559,7 +541,7 @@ gog_grid_line_xyz_render (GogGridLine *grid_line, GogView *view,
 				}
 			} else {
 				for (i = 0; i < tick_nbr; ++i) {
-					if (!((ticks[i].type == GOG_AXIS_TICK_MAJOR 
+					if (!((ticks[i].type == GOG_AXIS_TICK_MAJOR
 					       && !grid_line->is_minor) ||
 					      (ticks[i].type == GOG_AXIS_TICK_MINOR
 					       && grid_line->is_minor)))
@@ -843,7 +825,7 @@ gog_grid_line_view_render (GogView *view, gboolean stripes)
 	GogAxis *axis;
 	GogChart *chart;
 	GogView *chart_view;
-	GogStyle *style;
+	GOStyle *style;
 	GogAxisType axis_type;
 	GogAxisTick *ticks;
 	unsigned tick_nbr;
@@ -863,11 +845,11 @@ gog_grid_line_view_render (GogView *view, gboolean stripes)
 		return;
 
 	plot_area = gog_chart_view_get_plot_area (chart_view);
-	style = gog_styled_object_get_style (GOG_STYLED_OBJECT (grid_line));
+	style = go_styled_object_get_style (GO_STYLED_OBJECT (grid_line));
 	gog_renderer_push_style (view->renderer, style);
 
-	if ((!stripes && gog_style_is_line_visible (style)) ||
-	    (stripes && (style->fill.type != GOG_FILL_STYLE_NONE))) {
+	if ((!stripes && go_style_is_line_visible (style)) ||
+	    (stripes && (style->fill.type != GO_STYLE_FILL_NONE))) {
 		if (gog_chart_get_axis_set (chart) == GOG_AXIS_SET_XYZ) {
 			gog_grid_line_xyz_render (grid_line, view, axis,
 			                          ticks, tick_nbr, chart,
@@ -881,14 +863,14 @@ gog_grid_line_view_render (GogView *view, gboolean stripes)
 								 plot_area, stripes);
 					break;
 
-				case GOG_AXIS_RADIAL: 
-					gog_grid_line_radial_render (grid_line, view, 
+				case GOG_AXIS_RADIAL:
+					gog_grid_line_radial_render (grid_line, view,
 								     axis, ticks, tick_nbr,
 								     chart, plot_area, stripes);
 					break;
-					      
-				case GOG_AXIS_CIRCULAR: 
-					gog_grid_line_circular_render (grid_line, view, 
+
+				case GOG_AXIS_CIRCULAR:
+					gog_grid_line_circular_render (grid_line, view,
 								       axis, ticks, tick_nbr,
 								       chart, plot_area, stripes);
 					break;
@@ -916,4 +898,4 @@ gog_grid_line_view_render_lines (GogView *view)
 
 static GSF_CLASS (GogGridLineView, gog_grid_line_view,
 	   NULL /* gog_grid_line_view_class_init */, NULL,
-	   GOG_VIEW_TYPE)
+	   GOG_TYPE_VIEW)
