@@ -214,7 +214,7 @@ gog_series_element_class_init (GogSeriesElementClass *klass)
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT | GOG_PARAM_FORCE_SAVE));
 }
 
-GSF_CLASS (GogSeriesElement, gog_series_element,
+GSF_CLASS_ABSTRACT (GogSeriesElement, gog_series_element,
 	   gog_series_element_class_init, NULL /*gog_series_element_init*/,
 	   GOG_TYPE_STYLED_OBJECT)
 
@@ -267,7 +267,7 @@ role_series_element_allocate (GogObject *series)
 	GogObject *gse;
 
 	if (type == 0)
-		type = GOG_TYPE_SERIES_ELEMENT;
+		return NULL;
 
 	gse = g_object_new (type, NULL);
 	if (gse != NULL)
@@ -557,14 +557,17 @@ gog_series_populate_editor (GogObject *gobj,
 				GtkWidget *w;
 				widget = go_gtk_builder_get_widget (gui, "clamps-table");
 				w = GTK_WIDGET (gog_data_allocator_editor (dalloc, clamp_set, 0, GOG_DATA_SCALAR));
+				gtk_widget_set_tooltip_text (w, _("Derivative at first point of the clamped cubic spline."));
 				gtk_widget_show (w);
 				gtk_table_attach (GTK_TABLE (widget), w, 1, 2, 0, 1, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 				w = GTK_WIDGET (gog_data_allocator_editor (dalloc, clamp_set, 1, GOG_DATA_SCALAR));
+				gtk_widget_set_tooltip_text (w, _("Derivative at last point of the clamped cubic spline."));
 				gtk_widget_show (w);
 				gtk_table_attach (GTK_TABLE (widget), w, 1, 2, 1, 2, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 				if (series->interpolation != GO_LINE_INTERPOLATION_CLAMPED_CUBIC_SPLINE)
 					gtk_widget_hide (widget);
 			}
+			g_object_set_data (G_OBJECT (combo), "gui", gui);
 			g_signal_connect_swapped (G_OBJECT (combo), "destroy", G_CALLBACK (g_object_unref), gui);
 		}
 	}
@@ -602,6 +605,13 @@ gog_series_update (GogObject *obj)
 	series->needs_recalc = FALSE;
 }
 
+static void
+gog_series_child_added (GogObject *parent, GogObject *child)
+{
+	if (GOG_IS_TREND_LINE (child))
+		gog_plot_request_cardinality_update (GOG_SERIES (parent)->plot);
+}
+
 static void
 gog_series_init_style (GogStyledObject *gso, GOStyle *style)
 {
@@ -655,6 +665,8 @@ gog_series_class_init (GogSeriesClass *klass)
 	gog_klass->populate_editor	= gog_series_populate_editor;
 #endif
 	gog_klass->update		= gog_series_update;
+	gog_klass->child_added		= gog_series_child_added;
+	gog_klass->child_removed	= gog_series_child_added;
 	style_klass->init_style 	= gog_series_init_style;
 	/* series do not have views, so just forward signals from the plot */
 	gog_klass->use_parent_as_proxy  = TRUE;
@@ -810,7 +822,7 @@ gog_series_dataset_init (GogDatasetClass *iface)
 
 GSF_CLASS_FULL (GogSeries, gog_series,
 		NULL, NULL, gog_series_class_init, NULL,
-		gog_series_init, GOG_TYPE_STYLED_OBJECT, 0,
+		gog_series_init, GOG_TYPE_STYLED_OBJECT, G_TYPE_FLAG_ABSTRACT,
 		GSF_INTERFACE (gog_series_dataset_init, GOG_TYPE_DATASET))
 
 /**
