@@ -20,10 +20,7 @@
  */
 
 #include <goffice/goffice-config.h>
-
-#include "go-color.h"
-#include "go-line.h"
-#include <goffice/math/go-math.h>
+#include <goffice/goffice.h>
 
 #include <string.h>
 #include <glib/gi18n-lib.h>
@@ -173,7 +170,7 @@ go_line_dash_as_label (GOLineDashType type)
 			break;
 		}
 	}
-	return ret;
+	return _(ret);
 }
 
 /**
@@ -346,3 +343,89 @@ go_line_interpolation_auto_skip	(GOLineInterpolation type)
 	}
 	return FALSE;
 }
+
+/* ------------------------------------------------------------------------- */
+
+static struct {
+	GOArrowType typ;
+	char const *name;
+} arrow_types[] = {
+	{ GO_LINE_NONE, "none" },
+	{ GO_ARROW_KITE, "kite" },
+	{ GO_ARROW_OVAL, "oval" }
+};
+
+char const *
+go_arrow_type_as_str (GOArrowType typ)
+{
+	unsigned ui;
+
+	for (ui = 0; ui < G_N_ELEMENTS (arrow_types); ui++)
+		if (typ == arrow_types[ui].typ)
+			return arrow_types[ui].name;
+
+	return NULL;
+}
+
+GOArrowType
+go_arrow_type_from_str (const char *name)
+{
+	unsigned ui;
+	GOArrowType ret = GO_ARROW_NONE;
+
+	for (ui = 0; ui < G_N_ELEMENTS (arrow_types); ui++) {
+		if (strcmp (arrow_types[ui].name, name) == 0) {
+			ret = arrow_types[ui].typ;
+			break;
+		}
+	}
+
+	return ret;
+}
+
+GType
+go_arrow_get_type (void)
+{
+	static GType t = 0;
+
+	if (t == 0) {
+		t = g_boxed_type_register_static ("GOArrow",
+			 (GBoxedCopyFunc)go_arrow_dup,
+			 (GBoxedFreeFunc)g_free);
+	}
+	return t;
+}
+
+void
+go_arrow_init (GOArrow *res, GOArrowType typ,
+	       double a, double b, double c)
+{
+	res->typ = typ;
+	res->a = a;
+	res->b = b;
+	res->c = c;
+}
+
+void
+go_arrow_clear (GOArrow *dst)
+{
+	go_arrow_init (dst, GO_ARROW_NONE, 0, 0, 0);
+}
+
+void
+go_arrow_init_kite (GOArrow *dst, double a, double b, double c)
+{
+	go_arrow_init (dst, GO_ARROW_KITE, a, b, c);
+}
+
+void
+go_arrow_init_oval (GOArrow *dst, double ra, double rb)
+{
+	go_arrow_init (dst, GO_ARROW_OVAL, ra, rb, 0);
+}
+
+GOArrow *
+go_arrow_dup (GOArrow *src)
+{
+	return g_memdup (src, sizeof (*src));
+}
